import click
from .parse_input import generate_question_answer_dict
from .generate_deck import generate_deck_type_sound, write_package


@click.command()
@click.argument("input")
@click.argument("output")
@click.argument("deck_name")
@click.option("--separator", default=" = ", help="Characters that separate the front and back of the cards")
def cli(input, deck_name, separator, output):
    """Generate and Anki deck from annotations on a text file"""

    question_answer_dict = generate_question_answer_dict(
        input=input,
        separator=separator
    )

    deck = generate_deck_type_sound(
        question_answer_dict=question_answer_dict,
        deck_name=deck_name,
    )

    write_package(deck, output)

    click.echo("Finished")



import genanki
import random

model_id = random.randrange(1 << 30, 1 << 31)
MODEL_SOUND = genanki.Model(
    model_id=model_id,
    name="Main model",
    fields=[
        {"name": "Question"},
        {"name": "Answer"},
        {"name": "Sound"},
    ],
    templates=[
        {
            "name": "Card to type",
            "qfmt": "{{Question}}<br>{{type:Answer}}",
            "afmt": "{{FrontSide}}<hr id='answer'>{{type:Answer}}<br>{{Sound}}",
        },
    ],
    css=""".card {
    font-family: arial;
    font-size: 20px;
    text-align: center;
    color: black;
    background-color: white;
}
"""
    )

MODELS = {
    "sound": MODEL_SOUND,
}
